BasicPixel class
Constructors
-
BasicPixel({required int color, required Point point})
-
Properties
-
color
↔ int
-
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
point
↔ Point
-
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
override